# Documentation Index

## Core

- `framework.md`
- `objects.md`
- `schema.md`
- `source_data_contract_v1.md`
- `quickstart_contract.md`

## Processing

- `clean.md`
- `filter.md`
- `label.md`
- `rate.md`
- `llm.md`
- `io.md`

## Extension and Operations

- `plugins.md`
- `plugins/api_contract.md`
- `plugins/author_guide.md`
- `plugins/compatibility.md`
- `performance.md`
